Either

Enum Either 

pub enum Either<L, R> {
    Left(L),
    Right(R),
}
A simple sum type for use in apomorphism and other schemes.

Left typically represents early termination (an already-computed Fix), while Right represents continuation (a seed to unfold further).

Variants



Left(L)



Right(R)

Implementations

Source

impl<L, R> Either<L, R>

pub fn either<T>(self, f: impl FnOnce(L) -> T, g: impl FnOnce(R) -> T) -> T

Eliminate an Either by providing handlers for both cases.

pub fn map_left<L2>(self, f: impl FnOnce(L) -> L2) -> Either<L2, R>

Map over the Left value, leaving Right unchanged.

pub fn map_right<R2>(self, f: impl FnOnce(R) -> R2) -> Either<L, R2>

Map over the Right value, leaving Left unchanged.